@@ -112,7 +112,7 @@ __PACKAGE__->mk_inherited_merging_accessors(qw( tt_args config_callback ));
 *plugins           = \&plugin;
 *add_plugins       = \&add_plugin;
 
-our $VERSION = '0.05000';
+our $VERSION = '0.05001';
 $VERSION = eval $VERSION;
 
 Class::C3::initialize();
@@ -2775,6 +2775,12 @@ Accepts both C<name> and C<type> arguments to narrow the returned results.
         type => 'Radio',
     });
 
+Accepts also an Regexp to search for results.
+
+    $form->get_elements({
+        name => qr/oo/,
+    });
+
 =head2 get_field
 
 Arguments: [%options]
@@ -2804,6 +2810,12 @@ Accepts both C<name> and C<type> arguments to narrow the returned results.
         type => 'Radio',
     });
 
+Accepts also an Regexp to search for results.
+
+    $form->get_elements({
+        name => qr/oo/,
+    });
+
 =head2 get_element
 
 Arguments: [%options]
@@ -2836,6 +2848,12 @@ results.
         type => 'Text',
     });
 
+Accepts also an Regexp to search for results.
+
+    $form->get_elements({
+        name => qr/oo/,
+    });
+
 See L</get_elements> for a non-recursive version.
 
 =head2 get_all_element
@@ -2856,6 +2874,12 @@ first element found.
         type => 'Text',
     });
 
+Accepts also an Regexp to search for results.
+
+    $form->get_elements({
+        name => qr/oo/,
+    });
+
 See L</get_all_elements> for a non-recursive version.
 
 =head2 get_deflators
