@@ -4,7 +4,7 @@ use strict;
 use base 'HTML::FormFu::Constraint::_others';
 use Class::C3;
 
-__PACKAGE__->mk_item_accessors( qw( minimum maximum ) );
+__PACKAGE__->mk_item_accessors(qw( minimum maximum ));
 
 *min = \&minimum;
 *max = \&maximum;
@@ -28,40 +28,45 @@ sub process {
     my $others = $self->others;
     return if !defined $others;
 
-    # get min/max values
-    my $min = defined $self->minimum ? $self->minimum
-            :                          1
-            ;
-
-    my $max = defined $self->maximum ? $self->maximum
-            :                          1 + scalar @$others;
-    
     # get field names to check
     my @names = ( $self->nested_name );
     push @names, ref $others ? @{$others} : $others;
 
+    # get min/max values
+    my $min
+        = defined $self->minimum
+        ? $self->minimum
+        : 1;
+
+    my $max
+        = defined $self->maximum
+        ? $self->maximum
+        : scalar @names;
+
     for my $name (@names) {
         my $value = $self->get_nested_hash_value( $params, $name );
 
         if ( ref $value eq 'ARRAY' ) {
             my @errors = eval { $self->constrain_values( $value, $params ) };
-            
+
             if ( !@errors && !$@ ) {
                 $count++;
             }
         }
         else {
             my $ok = eval { $self->constrain_value($value) };
-            
+
             if ( $ok && !$@ ) {
                 $count++;
             }
         }
     }
 
+    my $pass = ( $count < $min || $count > $max ) ? 0 : 1;
+
     return $self->mk_errors( {
-            pass => ( $count < $min || $count > $max ) ? 0 : 1,
-            failed => \@names,
+            pass   => $pass,
+            failed => $pass ? [] : \@names,
             names  => \@names,
         } );
 }
@@ -125,7 +130,7 @@ Default Value: 1
 
 =head2 attach_errors_to_others
 
-Default Value: 1
+Default Value: 0
 
 =head1 SEE ALSO
 
