@@ -3,27 +3,36 @@ package HTML::FormFu::Deflator::CompoundSplit;
 use strict;
 use base 'HTML::FormFu::Deflator';
 
-__PACKAGE__->mk_accessors(qw/ split join field_order /);
+use HTML::FormFu::Constants qw( $EMPTY_STR $SPACE );
+
+__PACKAGE__->mk_item_accessors(qw( split join ));
+
+__PACKAGE__->mk_accessors(qw( field_order ));
 
 sub deflator {
     my ( $self, $value ) = @_;
 
-    return unless defined $value && $value ne "";
+    return if !defined $value || $value eq $EMPTY_STR;
 
     my ( $multi, @fields ) = @{ $self->parent->get_fields };
 
-    my $split = $self->split;
-    $split = qr/ +/, if !defined $split;
+    my $split
+        = defined $self->split
+        ? $self->split
+        : qr/$SPACE+/;
 
-    my $join = $self->join;
-    $join = ' ' if !defined $join;
+    my $join
+        = defined $self->join
+        ? $self->join
+        : $SPACE;
 
     my @parts = CORE::split $split, $value;
 
     if ( my $order = $self->field_order ) {
         my @new_order;
 
-    FIELD: for my $i (@$order) {
+    FIELD:
+        for my $i (@$order) {
             for my $field (@fields) {
                 if ( $field->name eq $i ) {
                     push @new_order, $field;
