@@ -8,7 +8,7 @@ use HTML::FormFu::Constants qw( $EMPTY_STR );
 use DateTime::Format::Builder;
 use DateTime::Format::Strptime;
 
-__PACKAGE__->mk_item_accessors( qw( strptime time_zone _builder ) );
+__PACKAGE__->mk_item_accessors(qw( strptime time_zone _builder ));
 
 sub new {
     my $self = shift->next::method(@_);
@@ -56,6 +56,12 @@ sub inflator {
             $args{time_zone} = $self->time_zone;
         }
 
+        if (  !exists $args{locale}
+            && defined( my $locale = $self->locale ) )
+        {
+            $args{locale} = $locale;
+        }
+
         my $formatter = DateTime::Format::Strptime->new(%args);
 
         $dt->set_formatter($formatter);
@@ -106,10 +112,27 @@ HTML::FormFu::Inflator::DateTime - DateTime inflator
               params: [day, month, year]
             strptime: '%d-%m-%Y'
 
+An example of using the same parser declaration for both a DateTime
+constraint and a DateTime inflator, using YAML references:
+
+    ---
+    elements:
+      - type: Text
+        name: date
+        constraints:
+          - type: DateTime
+            parser: &PARSER
+              strptime: '%d-%m-%Y'
+        inflators:
+          - type: DateTime
+            parser: *PARSER
+
 =head1 DESCRIPTION
 
 Inflate dates into L<DateTime> objects.
 
+For a corresponding deflator, see L<HTML::FormFu::Deflator::Strftime>.
+
 =head1 METHODS
 
 =head2 parser
